summaryrefslogtreecommitdiff
path: root/tests
diff options
context:
space:
mode:
authorMuhammad Qureshi <muhammadq@google.com>2020-06-16 16:39:43 -0700
committerMuhammad Qureshi <muhammadq@google.com>2020-06-16 18:17:46 -0700
commit5e13ca55ad772b80c05b860d9c3ad616dd5684b3 (patch)
tree1514f18e2c80c3b7eb55f585886d7757d3abafba /tests
parentc7a1d6a7ddcfad8a3971a76765ec25ad86024f92 (diff)
Rename "Westworld" to "Statsd"
Bug: 158725651 Test: N/A; trivial name change Change-Id: Iedcdf61e2edc7404504fdce9030513f11d31bc66
Diffstat (limited to 'tests')
-rw-r--r--tests/wifitests/src/com/android/server/wifi/WifiDataStallTest.java2
-rw-r--r--tests/wifitests/src/com/android/server/wifi/WifiHealthMonitorTest.java2
-rw-r--r--tests/wifitests/src/com/android/server/wifi/WifiMetricsTest.java4
3 files changed, 4 insertions, 4 deletions
diff --git a/tests/wifitests/src/com/android/server/wifi/WifiDataStallTest.java b/tests/wifitests/src/com/android/server/wifi/WifiDataStallTest.java
index e374a9080..61979f1e8 100644
--- a/tests/wifitests/src/com/android/server/wifi/WifiDataStallTest.java
+++ b/tests/wifitests/src/com/android/server/wifi/WifiDataStallTest.java
@@ -535,7 +535,7 @@ public class WifiDataStallTest extends WifiBaseTest {
}
/**
- * Check WestWorld logging
+ * Check statsd logging
*/
@Test
public void testWifiStatsLogWrite() throws Exception {
diff --git a/tests/wifitests/src/com/android/server/wifi/WifiHealthMonitorTest.java b/tests/wifitests/src/com/android/server/wifi/WifiHealthMonitorTest.java
index 264fe9048..12796510e 100644
--- a/tests/wifitests/src/com/android/server/wifi/WifiHealthMonitorTest.java
+++ b/tests/wifitests/src/com/android/server/wifi/WifiHealthMonitorTest.java
@@ -541,7 +541,7 @@ public class WifiHealthMonitorTest extends WifiBaseTest {
}
/**
- * Check WestWorld logging after one daily detection with high non-local disconnection rate
+ * Check statsd logging after one daily detection with high non-local disconnection rate
*/
@Test
public void testWifiStatsLogWrite() throws Exception {
diff --git a/tests/wifitests/src/com/android/server/wifi/WifiMetricsTest.java b/tests/wifitests/src/com/android/server/wifi/WifiMetricsTest.java
index ca5ae268d..198eb079f 100644
--- a/tests/wifitests/src/com/android/server/wifi/WifiMetricsTest.java
+++ b/tests/wifitests/src/com/android/server/wifi/WifiMetricsTest.java
@@ -1947,10 +1947,10 @@ public class WifiMetricsTest extends WifiBaseTest {
}
/**
* Test logging to WestWorld when a connection event finishes.
*/
@Test
- public void testLogWifiConnectionResultWestworld() throws Exception {
+ public void testLogWifiConnectionResultStatsd() throws Exception {
// static mocking for WifiStatsLog
mSession = ExtendedMockito.mockitoSession()
.strictness(Strictness.LENIENT)
@@ -1947,10 +1947,10 @@ public class WifiMetricsTest extends WifiBaseTest {
}
/**
- * Test logging to WestWorld when a connection event finishes.
+ * Test logging to statsd when a connection event finishes.
*/